import unittest
import directio
import os
import resource
from test import test_support

class DirectioModuleTest(unittest.TestCase):
    def read_what_was_written(self, fd, buf):
        buf_tmp = ""
        while len(buf_tmp) < len(buf):
            buf_tmp += directio.read(fd, len(buf) - len(buf_tmp))
        if buf_tmp != buf:
            self.fail("failed in reading what has been written"%(buf_tmp,buf))

    def test_read_write(self):
		    flags = directio.O_RDWR | directio.O_CREAT
        fd = directio.open("tmp_directio_file", flags, 0644)
        buf = "a"*resource.getpagesize()
        sent = 0
        while sent < len(buf):
            count = directio.write(fd, buf[sent:])
            sent += count
        os.lseek(fd, 0, 0)
        self.read_what_was_written(fd, buf)
        directio.close(fd)
        os.unlink("tmp_directio_file")
						
        

def test_main():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(DirectioModuleTest))
    test_support.run_suite(suite)

if __name__ == "__main__":
    test_main()



from distutils.core import setup, Extension

LONG_DESCRIPTION = '\
This is an interface to open(), read(), write() and close() on a direct I/O \
context (O_DIRECT flag) from the Python programming language.\n\
\n\
These system calls are Linux system calls to\n\
* open a file with the O_DIRECT flag, and close it.\n\
* read or write from the file ignores the buffer cache.\n\
\n\
The O_DIRECT flag introduced in SGI IRIX, where it has alignment \
restrictions similar to those of Linux 2.4. FreeBSD 4.x introduced a \
flag of the same name, but without alignment restrictions. Support was \
added under Linux in kernel version 2.4.10. Older Linux kernels simply \
ignore this flag.\n\
'

classifiers = """\
Development Status :: 3 - Alpha
Intended Audience :: Developers
License :: OSI Approved :: GNU General Public License (GPL)
Programming Language :: Python
Topic :: Software Development :: Libraries :: Python Modules
Operating System :: POSIX :: Linux
"""

module1 = Extension('directio',
                    sources = ['directiomodule.c'])

setup (name = 'directio',
       version = '1.0',
       author = 'Omar Ait Mous',
       author_email = 'dev.python.directio@enix.fr',
       maintainer = 'Omar Ait Mous',
       maintainer_email = 'dev.python.directio@enix.fr',
       url = 'www.enix.org',
       license = 'http://www.gnu.org/licenses/gpl.txt',
       platforms = ['Linux'],
       description = 'A Python interface to open/read/write on a direct I/O \
context.',
       long_description = LONG_DESCRIPTION,
       classifiers = filter(None, classifiers.split("\n")),
       ext_modules = [module1])
